@@ -127,7 +127,7 @@ func TestBindAsMaintenanceUser(t *testing.T) {
 	mock := newMockDriver()
 	settings := internal.Settings{
 		Root:         "foo",
-		BindUserName: "bar",
+		BindUserDN:   "cn=bar",
 		BindPassword: "boz",
 	}
 	controller := internal.NewLDAPController(settings, mock)
@@ -139,7 +139,7 @@ func TestBindAsMaintenanceUser(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, mock.calls, 1)
 	require.Equal(t, "SimpleBind", mock.calls[0].name)
-	require.Equal(t, "cn=bar,foo", mock.calls[0].arguments["userDN"])
+	require.Equal(t, "cn=bar", mock.calls[0].arguments["userDN"])
 	require.Equal(t, "boz", mock.calls[0].arguments["password"])
 	require.False(t, mock.calls[0].arguments["allowEmptyPassword"].(bool))
 }
@@ -149,7 +149,7 @@ func TestBindAsMaintenanceUserWithEmptyPassword(t *testing.T) {
 	mock := newMockDriver()
 	settings := internal.Settings{
 		Root:         "foo",
-		BindUserName: "bar",
+		BindUserDN:   "cn=bar",
 		BindPassword: "",
 	}
 	controller := internal.NewLDAPController(settings, mock)
@@ -161,7 +161,7 @@ func TestBindAsMaintenanceUserWithEmptyPassword(t *testing.T) {
 	require.NoError(t, err)
 	require.Len(t, mock.calls, 1)
 	require.Equal(t, "SimpleBind", mock.calls[0].name)
-	require.Equal(t, "cn=bar,foo", mock.calls[0].arguments["userDN"])
+	require.Equal(t, "cn=bar", mock.calls[0].arguments["userDN"])
 	require.Empty(t, mock.calls[0].arguments["password"])
 	require.True(t, mock.calls[0].arguments["allowEmptyPassword"].(bool))
 }
